//
//  Transit.hpp
//  Tycho
//
//  Created by Michael McLaughlin on 9/26/21.
//
//  Code requires the AA+ library (not included in Supplementary Material)
//  Version used = 2.30
//  Ref: http://www.naughter.com/aa.html

#ifndef Transit_hpp
#define Transit_hpp

#include "AA+.h"
#include "AADefines.h"
#include <math.h>

struct dblPair {
   double x, y;
};

class Transit {
public:
   Transit();
   ~Transit() = default;
   
   void getSolarTransit(long year, long month, long day, bool isGregorian = false);

   double date, transitAltitude, transitTime;
private:
   double getSolarAltitude(double time);
   
   // Backup function when normal search fails
   // Find x in [a, b] that optimize getSolarAltitude.
   dblPair GSSearch(double a, double b, double epsilon, bool maximize = true);
   dblPair GSSearch2(double a, double b, double epsilon, double h,
                     bool not_in_C, double c, double fc, bool not_in_D, double d, double fd, bool maximize);

   double ULat, ULong;  // Uraniborg
};

#endif /* Transit_hpp */
