//
//  main.cpp
//  Tycho
//
//  Created by Michael McLaughlin on 11/13/21.
//
//  Code requires the AA+ library (not included in Supplementary Material)
//  Version used = 2.30
//  Ref: http://www.naughter.com/aa.html

#include <iostream>
#include <fstream>
#include <iomanip>
#include "Transit.hpp"

using namespace std;

// filenames (assumed local)
const string inputFn = string("transitIn.txt");
const string outputFn = string("transitOut.txt");
const string dataFn = string("transit.dat");          // MacMCMC datafile

int main(int argc, const char * argv[]) {
   Transit transit;
   string header, CR;
   double deg, min, sec, observed, trueAlt, error;    // altitude in degrees; error in minutes
   long y, m, d, instrument;
   ifstream input(inputFn);
   ofstream output(outputFn), mcmcData(dataFn);
   
   double start = CAADate(1588, 1, 1, false);   // Julian Day = 2301074.5
   
   if (!input.fail()) {
      output << "year" << '\t' << "month" << '\t' << "day" << '\t' << "instrument" << '\t' << "trueAlt" << '\t'
                << "error" << endl;
      mcmcData << "time" << '\t' << "instrument" << '\t' << "error" << endl;
      input >> header >> header >> header >> header >> header >> header >> header;
      while ((bool)(input >> y >> m >> d >> instrument >> deg >> min >> sec)) {
         observed = CAACoordinateTransformation::DMSToDegrees(deg, min, sec);
         transit.getSolarTransit(y, m, d);
         trueAlt = transit.transitAltitude;
         error = 60*(observed - trueAlt);
         output << y  << '\t' << m << '\t' << d << '\t' << instrument << '\t' << trueAlt << '\t' << error << endl;
         mcmcData << transit.transitTime - start << '\t' << instrument << '\t' << error << endl;
      }
   }
   else
      cout << inputFn << " not found!" << endl;
   
   cout << "Finished." << endl;

   return 0;
}
